package Plugins::AlbumReview::Settings;

use strict;
use base qw(Slim::Web::Settings);
use Slim::Utils::Log;
use Slim::Utils::Prefs;

my $prefs = preferences('plugin.albumreview');

my $log = Slim::Utils::Log->addLogCategory({
	'category'     => 'plugin.albumreview',
	'defaultLevel' => 'ERROR',
	'description'  => 'PLUGIN_ALBUMREVIEW',
});

my $cacheFolder;

sub new {
	my $class = shift;
	$class->_initCacheFolder();
	return $class->SUPER::new();
}

sub name {
	return 'PLUGIN_ALBUMREVIEW';
}

sub page {
	return 'plugins/AlbumReview/settings.html';
}

sub prefs {
	return ($prefs, qw(
		plugin_albumreview_refresh
		plugin_albumreview_remove_brackets
		plugin_albumreview_cache
	));
}

sub handler {
	my ($class, $client, $paramRef, $pageSetup) = @_;
	
	if ($paramRef->{'pref_plugin_albumreview_cache_reset'}) { 
		$class->_flushCacheFolder(); 
	}

	if ($paramRef->{'pref_plugin_albumreview_cache'} 
		&& $paramRef->{'pref_plugin_albumreview_cache'} != $prefs->get('pref_plugin_albumreview_cache')) { 
		$class->_initCacheFolder(); 
	}

	return $class->SUPER::handler($client, $paramRef, $pageSetup);
}

sub getCacheFolder {
	return $cacheFolder;
}

sub _flushCacheFolder {
	my $class = shift;
	$log->debug("Flushing cache...");
	$class->_initCacheFolder(-1);
}

sub _initCacheFolder {
	my ($class, $cacheAge) = @_;

	$log->debug("initializing cache folder...");

	$cacheFolder = preferences('server')->get('cachedir');

	mkdir($cacheFolder) unless (-d $cacheFolder);

	$cacheFolder .= "/slimserver-albumreview-cache";

	mkdir($cacheFolder) unless (-d $cacheFolder);
	
	if (not defined $cacheAge) {
		$cacheAge = $prefs->get('plugin_albumreview_cache');
	}
	
	# purge the cache
	if (opendir(DIR, $cacheFolder)) {
		while (defined(my $cachedFile = readdir(DIR))) {
			
			next if ($cachedFile eq '.' || $cachedFile eq '..');
	
			$cachedFile = "$cacheFolder/$cachedFile";
			if (-M $cachedFile > $cacheAge) {
				unlink $cachedFile;
			}
		}
	}
	else {
		$log->debug("can't opendir $cacheFolder: $!");
	}

	closedir(DIR);
	
	# set timer to purge cache once a day
	Slim::Utils::Timers::killTimers($class, \&_initCacheFolder);
	Slim::Utils::Timers::setTimer($class, Time::HiRes::time() + 60*60*24, \&_initCacheFolder);
	
	return $cacheFolder;
}

1;